@@ -133,7 +133,7 @@ class BackupJob {
             $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -cf " . escapeshellarg($tarFile) . " " . escapeshellarg($userName . "/" . $domainName) . " && pigz -6 -c " . escapeshellarg($tarFile) . " > " . escapeshellarg($tempFile) . " && rm -f " . escapeshellarg($tarFile);
         } else {
             // Fall back to standard tar with gzip compression (level 6 for better speed/ratio balance)
-            $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -czf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/" . $domainName);
+            $command = "cd " . escapeshellarg(dirname($userDir)) . " && tar -cf " . escapeshellarg($tempFile) . " --use-compress-program='gzip -6' " . escapeshellarg($userName . "/" . $domainName);
         }
         
         exec($command, $output, $returnCode);
