@@ -716,5 +716,41 @@ class haproxy_manager {
         
         return false;
     }
+    
+    /**
+     * Safe configuration reload with validation and rollback
+     * 
+     * @return array Result array with success/error status
+     */
+    public function safe_config_reload() {
+        $result = $this->makeApiRequest('POST', '/api/config/reload');
+        
+        if ($result['success']) {
+            error_log("HAProxy Manager: Safe configuration reload completed successfully");
+            return $result;
+        }
+        
+        error_log("HAProxy Manager: Safe configuration reload failed - " . ($result['error'] ?? 'Unknown error'));
+        return $result;
+    }
+    
+    /**
+     * Synchronize blocked IPs from database to HAProxy runtime map
+     * 
+     * @return array Result array with success/error status including sync statistics
+     */
+    public function sync_blocked_ips() {
+        $result = $this->makeApiRequest('POST', '/api/blocked-ips/sync');
+        
+        if ($result['success']) {
+            $total_ips = $result['data']['total_ips'] ?? 0;
+            $synced_ips = $result['data']['synced_ips'] ?? 0;
+            error_log("HAProxy Manager: Blocked IPs sync completed - $synced_ips/$total_ips IPs synced");
+            return $result;
+        }
+        
+        error_log("HAProxy Manager: Blocked IPs sync failed - " . ($result['error'] ?? 'Unknown error'));
+        return $result;
+    }
 }
 ?> 
\ No newline at end of file
