@@ -129,7 +129,7 @@ class log_monitor_manager {
             'ftp_block_duration' => ['3600', 'FTP IP block duration in seconds (1 hour)'],
             'log_check_interval' => ['300', 'How often to check logs in seconds (5 minutes)'],
             'ssh_log_file' => ['/var/log/secure', 'SSH/Auth log file path'],
-            'ftp_log_file' => ['/var/log/proftpd/auth.log', 'FTP log file path'],
+            'ftp_log_file' => ['/var/log/proftpd/access.log', 'FTP log file path'],
             'blocking_method' => ['service', 'IP blocking method (service=service-level, iptables=firewall-level)'],
             'docker_network_preserve' => ['1', 'Preserve Docker network access when blocking IPs']
         ];
@@ -485,11 +485,12 @@ class log_monitor_manager {
             return;
         }
         
-        // ProFTPD auth.log format for failed logins
+        // ProFTPD access.log format for failed logins
         // Format can be either:
         // 1. IP_ADDRESS username - [timestamp] "PASS (hidden)" 530 -
         // 2. hostname username - [timestamp] "PASS (hidden)" 530 -
         // Status code 530 means authentication failed
+        // access.log typically has more complete logging than auth.log
         
         // First try to extract IP from the first field (could be IP or hostname)
         if (preg_match('/^(\S+)\s+(\S+)\s+-\s+\[.*?\]\s+"PASS \(hidden\)" 530/', $line, $matches)) {
@@ -668,7 +669,7 @@ class log_monitor_manager {
         }
         
         // Check if IP is already blocked for this service to prevent infinite loops
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND unblock_time > ?');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
         $stmt->bindValue(2, $ip, SQLITE3_TEXT);
         $stmt->bindValue(3, time(), SQLITE3_INTEGER);
@@ -728,7 +729,7 @@ class log_monitor_manager {
         }
         
         // Get all services this IP is blocked from
-        $stmt = $this->db->prepare('SELECT DISTINCT service_type FROM service_blocked_ips WHERE ip_address = ? AND unblock_time > ?');
+        $stmt = $this->db->prepare('SELECT DISTINCT service_type FROM service_blocked_ips WHERE ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
         $stmt->bindValue(1, $ip, SQLITE3_TEXT);
         $stmt->bindValue(2, time(), SQLITE3_INTEGER);
         $result = $stmt->execute();
@@ -917,7 +918,7 @@ class log_monitor_manager {
     }
     
     public function is_service_ip_blocked($service, $ip) {
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND unblock_time > ?');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND ip_address = ? AND (unblock_time > ? OR unblock_time = 0)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
         $stmt->bindValue(2, $ip, SQLITE3_TEXT);
         $stmt->bindValue(3, time(), SQLITE3_INTEGER);
@@ -1166,11 +1167,11 @@ class log_monitor_manager {
     
     public function get_service_blocked_ips($service = null) {
         if ($service) {
-            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND unblock_time > ? ORDER BY block_time DESC');
+            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = 0) ORDER BY block_time DESC');
             $stmt->bindValue(1, $service, SQLITE3_TEXT);
             $stmt->bindValue(2, time(), SQLITE3_INTEGER);
         } else {
-            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? ORDER BY block_time DESC');
+            $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0 ORDER BY block_time DESC');
             $stmt->bindValue(1, time(), SQLITE3_INTEGER);
         }
         
@@ -1189,7 +1190,7 @@ class log_monitor_manager {
      * @return array Array of unique blocked IPs with original blocking service
      */
     public function get_unique_blocked_ips() {
-        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? ORDER BY ip_address, block_time ASC');
+        $stmt = $this->db->prepare('SELECT * FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0 ORDER BY ip_address, block_time ASC');
         $stmt->bindValue(1, time(), SQLITE3_INTEGER);
         
         $result = $stmt->execute();
@@ -1216,6 +1217,126 @@ class log_monitor_manager {
         return array_values($blocked_by_ip); // Return indexed array
     }
     
+    /**
+     * Sync blocked IPs across all services to ensure consistency
+     * 
+     * @return array Array with sync results and statistics
+     */
+    public function sync_blocked_ips() {
+        $results = [
+            'success' => true,
+            'synced_count' => 0,
+            'errors' => [],
+            'details' => []
+        ];
+        
+        try {
+            // Get all currently blocked IPs from service database
+            $stmt = $this->db->prepare('SELECT DISTINCT ip_address, reason FROM service_blocked_ips WHERE unblock_time > ? OR unblock_time = 0');
+            $stmt->bindValue(1, time(), SQLITE3_INTEGER);
+            $result = $stmt->execute();
+            
+            $service_blocked_ips = [];
+            while ($row = $result->fetchArray(SQLITE3_ASSOC)) {
+                $service_blocked_ips[] = [
+                    'ip' => $row['ip_address'],
+                    'reason' => $row['reason'] ?? 'Service block sync'
+                ];
+            }
+            
+            if (empty($service_blocked_ips)) {
+                $results['details'][] = 'No blocked IPs found in service database';
+                return $results;
+            }
+            
+            // Initialize managers
+            require_once('/docker/whp/web/libs/security_manager.php');
+            $security_manager = new security_manager();
+            
+            $haproxy_available = class_exists('haproxy_manager');
+            $haproxy_manager = null;
+            if ($haproxy_available) {
+                $haproxy_manager = new haproxy_manager();
+            }
+            
+            // Sync each IP to all services
+            foreach ($service_blocked_ips as $blocked_ip) {
+                $ip = $blocked_ip['ip'];
+                $reason = $blocked_ip['reason'];
+                $ip_synced = false;
+                
+                // Sync to Security Manager
+                try {
+                    if (!$this->is_ip_blocked_in_security_manager($security_manager, $ip)) {
+                        $security_manager->block_ip($ip, $reason . ' (sync)', 0, false, true); // Skip service blocks to prevent loop
+                        $ip_synced = true;
+                        $results['details'][] = "Synced $ip to Security Manager";
+                    }
+                } catch (Exception $e) {
+                    $results['errors'][] = "Security Manager sync failed for $ip: " . $e->getMessage();
+                    error_log("Security Manager sync error for IP $ip: " . $e->getMessage());
+                }
+                
+                // Sync to HAProxy if available
+                if ($haproxy_available && $haproxy_manager) {
+                    try {
+                        if (!$this->is_ip_blocked_in_haproxy($haproxy_manager, $ip)) {
+                            $haproxy_manager->block_ip($ip, $reason . ' (sync)', 'WHP Sync');
+                            $ip_synced = true;
+                            $results['details'][] = "Synced $ip to HAProxy";
+                        }
+                    } catch (Exception $e) {
+                        $results['errors'][] = "HAProxy sync failed for $ip: " . $e->getMessage();
+                        error_log("HAProxy sync error for IP $ip: " . $e->getMessage());
+                    }
+                }
+                
+                if ($ip_synced) {
+                    $results['synced_count']++;
+                }
+            }
+            
+            if ($results['synced_count'] == 0 && empty($results['errors'])) {
+                $results['details'][] = 'All services are already in sync - no changes needed';
+            }
+            
+        } catch (Exception $e) {
+            $results['success'] = false;
+            $results['errors'][] = 'Sync operation failed: ' . $e->getMessage();
+            error_log("IP sync operation failed: " . $e->getMessage());
+        }
+        
+        return $results;
+    }
+    
+    /**
+     * Check if IP is blocked in Security Manager
+     */
+    private function is_ip_blocked_in_security_manager($security_manager, $ip) {
+        $blocked_ips = $security_manager->get_blocked_ips();
+        foreach ($blocked_ips as $blocked) {
+            if ($blocked['ip_address'] === $ip) {
+                return true;
+            }
+        }
+        return false;
+    }
+    
+    /**
+     * Check if IP is blocked in HAProxy
+     */
+    private function is_ip_blocked_in_haproxy($haproxy_manager, $ip) {
+        $blocked_ips = $haproxy_manager->get_blocked_ips();
+        if ($blocked_ips && is_array($blocked_ips)) {
+            foreach ($blocked_ips as $blocked) {
+                if (is_array($blocked) && isset($blocked['ip_address']) && $blocked['ip_address'] === $ip) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+    
     public function get_service_failed_attempts($service, $hours = 24) {
         $stmt = $this->db->prepare('SELECT * FROM service_failed_attempts WHERE service_type = ? AND attempt_time > ? ORDER BY attempt_time DESC');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
@@ -1241,7 +1362,7 @@ class log_monitor_manager {
             );
             
             // Get blocked IPs count
-            $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM service_blocked_ips WHERE service_type = ? AND unblock_time > ?');
+            $stmt = $this->db->prepare('SELECT COUNT(*) as count FROM service_blocked_ips WHERE service_type = ? AND (unblock_time > ? OR unblock_time = 0)');
             $stmt->bindValue(1, $service, SQLITE3_TEXT);
             $stmt->bindValue(2, time(), SQLITE3_INTEGER);
             $result = $stmt->execute();
